@@ -15,6 +15,7 @@ DEFAULT_KINDS = [
     # Do not sort this list, order matters.
     {"jinja2": "**/*.j2"},  # jinja2 templates are not always parsable as something else
     {"jinja2": "**/*.j2.*"},
+    {"inventory": "**/inventory/**.yml"},
     {"requirements": "**/meta/requirements.yml"},  # v1 only
     # https://docs.ansible.com/ansible/latest/dev_guide/collections_galaxy_meta.html
     {"galaxy": "**/galaxy.yml"},  # Galaxy collection meta
@@ -59,6 +60,7 @@ BASE_KINDS = [
 
 
 options = Namespace(
+    cache_dir=None,
     colored=True,
     configured=False,
     cwd=".",
@@ -79,6 +81,7 @@ options = Namespace(
     mock_modules=[],
     mock_roles=[],
     loop_var_prefix=None,
+    var_naming_pattern=None,
     offline=False,
     project_dir=".",  # default should be valid folder (do not use None here)
     extra_vars=None,
@@ -96,7 +99,10 @@ collection_list: List[str] = []
 
 def get_rule_config(rule_id: str) -> Dict[str, Any]:
     """Get configurations for the rule ``rule_id``."""
-    return options.rules.get(rule_id, dict())
+    rule_config = options.rules.get(rule_id, dict())
+    if not isinstance(rule_config, dict):
+        raise RuntimeError("Invalid rule config for %s: %s" % (rule_id, rule_config))
+    return rule_config
 
 
 @lru_cache()
@@ -115,12 +121,14 @@ def ansible_collections_path() -> str:
 
 def parse_ansible_version(stdout: str) -> Tuple[str, Optional[str]]:
     """Parse output of 'ansible --version'."""
+    # Ansible can produce extra output before displaying version in debug mode.
+
     # ansible-core 2.11+: 'ansible [core 2.11.3]'
-    match = re.match(r"^ansible \[(?:core|base) ([^\]]+)\]", stdout)
+    match = re.search(r"^ansible \[(?:core|base) ([^\]]+)\]", stdout, re.MULTILINE)
     if match:
         return match.group(1), None
     # ansible-base 2.10 and Ansible 2.9: 'ansible 2.x.y'
-    match = re.match(r"^ansible ([^\s]+)", stdout)
+    match = re.search(r"^ansible ([^\s]+)", stdout, re.MULTILINE)
     if match:
         return match.group(1), None
     return "", "FATAL: Unable parse ansible cli version: %s" % stdout
