@@ -2,6 +2,7 @@
 import copy
 import logging
 import os
+import pathlib
 import subprocess
 import sys
 from argparse import Namespace
@@ -11,7 +12,9 @@ from pathlib import Path
 from tempfile import NamedTemporaryFile
 from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, Set, Union
 
+# import wcmatch
 import wcmatch.pathlib
+from wcmatch.wcmatch import RECURSIVE, WcMatch
 
 from ansiblelint.config import BASE_KINDS, options
 from ansiblelint.constants import FileType
@@ -141,6 +144,7 @@ class Lintable:
                 self.role = role.name
 
         if str(self.path) in ['/dev/stdin', '-']:
+            # pylint: disable=consider-using-with
             self.file = NamedTemporaryFile(mode="w+", suffix="playbook.yml")
             self.filename = self.file.name
             self._content = sys.stdin.read()
@@ -200,22 +204,38 @@ class Lintable:
         return f"{self.name} ({self.kind})"
 
 
-def get_yaml_files(options: Namespace) -> Dict[str, Any]:
-    """Find all yaml files."""
+def discover_lintables(options: Namespace) -> Dict[str, Any]:
+    """Find all files that we know how to lint."""
     # git is preferred as it also considers .gitignore
-    git_command = ['git', 'ls-files', '-z']
-    _logger.info("Discovering files to lint: %s", ' '.join(git_command))
-
+    git_command_present = [
+        'git',
+        'ls-files',
+        '--cached',
+        '--others',
+        '--exclude-standard',
+        '-z',
+    ]
+    git_command_absent = ['git', 'ls-files', '--deleted', '-z']
     out = None
 
     try:
-        out = subprocess.check_output(
-            git_command, stderr=subprocess.STDOUT, universal_newlines=True
+        out_present = subprocess.check_output(
+            git_command_present, stderr=subprocess.STDOUT, universal_newlines=True
         ).split("\x00")[:-1]
+        _logger.info(
+            "Discovered files to lint using: %s", ' '.join(git_command_present)
+        )
+
+        out_absent = subprocess.check_output(
+            git_command_absent, stderr=subprocess.STDOUT, universal_newlines=True
+        ).split("\x00")[:-1]
+        _logger.info("Excluded removed files using: %s", ' '.join(git_command_absent))
+
+        out = set(out_present) - set(out_absent)
     except subprocess.CalledProcessError as exc:
         if not (exc.returncode == 128 and 'fatal: not a git repository' in exc.output):
             _logger.warning(
-                "Failed to discover yaml files to lint using git: %s",
+                "Failed to discover lintable files using git: %s",
                 exc.output.rstrip('\n'),
             )
     except FileNotFoundError as exc:
@@ -223,34 +243,54 @@ def get_yaml_files(options: Namespace) -> Dict[str, Any]:
             _logger.warning("Failed to locate command: %s", exc)
 
     if out is None:
-        out = [
-            os.path.join(root, name)
-            for root, dirs, files in os.walk('.')
-            for name in files
-            if name.endswith('.yaml') or name.endswith('.yml')
-        ]
+        exclude_pattern = "|".join(str(x) for x in options.exclude_paths)
+        _logger.info("Looking up for files, excluding %s ...", exclude_pattern)
+        out = WcMatch(
+            '.', exclude_pattern=exclude_pattern, flags=RECURSIVE, limit=256
+        ).match()
 
     return OrderedDict.fromkeys(sorted(out))
 
 
-def guess_project_dir() -> str:
-    """Return detected project dir or user home directory."""
-    try:
-        result = subprocess.run(
-            ["git", "rev-parse", "--show-toplevel"],
-            stderr=subprocess.PIPE,
-            stdout=subprocess.PIPE,
-            universal_newlines=True,
-            check=False,
-        )
-    except FileNotFoundError:
-        # if git is absent we use home directory
-        return str(Path.home())
+def guess_project_dir(config_file: Optional[str]) -> str:
+    """Return detected project dir or current working directory."""
+    path = None
+    if config_file is not None:
+        target = pathlib.Path(config_file)
+        if target.exists():
+            path = str(target.parent.absolute())
 
-    if result.returncode != 0:
-        return str(Path.home())
+    if path is None:
+        try:
+            result = subprocess.run(
+                ["git", "rev-parse", "--show-toplevel"],
+                stderr=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                universal_newlines=True,
+                check=True,
+            )
 
-    return result.stdout.splitlines()[0]
+            path = result.stdout.splitlines()[0]
+        except subprocess.CalledProcessError as exc:
+            if not (
+                exc.returncode == 128 and 'fatal: not a git repository' in exc.stderr
+            ):
+                _logger.warning(
+                    "Failed to guess project directory using git: %s",
+                    exc.stderr.rstrip('\n'),
+                )
+        except FileNotFoundError as exc:
+            _logger.warning("Failed to locate command: %s", exc)
+
+    if path is None:
+        path = os.getcwd()
+
+    _logger.info(
+        "Guessed %s as project root directory",
+        path,
+    )
+
+    return path
 
 
 def expand_dirs_in_lintables(lintables: Set[Lintable]) -> None:
@@ -264,7 +304,7 @@ def expand_dirs_in_lintables(lintables: Set[Lintable]) -> None:
 
     if should_expand:
         # this relies on git and we do not want to call unless needed
-        all_files = get_yaml_files(options)
+        all_files = discover_lintables(options)
 
         for item in copy.copy(lintables):
             if item.path.is_dir():
