@@ -44,12 +44,12 @@ class RoleNames(AnsibleLintRule):
     description = (
         "Role names are now limited to contain only lowercase alphanumeric "
         "characters, plus '_' and start with an alpha character. See "
-        "`developing collections <https://docs.ansible.com/ansible/devel/dev_guide/developing_"
-        "collections.html#roles-directory>`_"
+        "`developing collections <https://docs.ansible.com/ansible/devel/dev_guide/"
+        "developing_collections_structure.html#roles-directory>`_"
     )
     severity = 'HIGH'
     done: List[str] = []  # already noticed roles list
-    tags = ['deprecations']
+    tags = ['deprecations', 'metadata']
     version_added = 'v4.3.0'
 
     def __init__(self) -> None:
@@ -76,7 +76,7 @@ class RoleNames(AnsibleLintRule):
         role_name = _remove_prefix(role_name, "ansible-role-")
         if role_name not in self.done:
             self.done.append(role_name)
-            if not self._re.match(role_name):
+            if role_name and not self._re.match(role_name):
                 result.append(
                     self.create_matcherror(
                         filename=str(file.path),
