@@ -22,9 +22,10 @@
 import logging
 from functools import lru_cache
 from itertools import product
-from typing import TYPE_CHECKING, Any, Generator, List, Sequence
+from typing import TYPE_CHECKING, Any, Generator, List, Optional, Sequence
 
-import ruamel.yaml
+# Module 'ruamel.yaml' does not explicitly export attribute 'YAML'; implicit reexport disabled
+from ruamel.yaml import YAML  # type: ignore
 
 from ansiblelint.config import used_old_tags
 from ansiblelint.constants import RENAMED_TAGS
@@ -33,7 +34,6 @@ from ansiblelint.file_utils import Lintable
 if TYPE_CHECKING:
     from ansible.parsing.yaml.objects import AnsibleBaseYAMLObject
 
-
 _logger = logging.getLogger(__name__)
 
 
@@ -43,7 +43,7 @@ _logger = logging.getLogger(__name__)
 # ansible.parsing.yaml.objects.AnsibleSequence
 
 
-def get_rule_skips_from_line(line: str) -> List:
+def get_rule_skips_from_line(line: str) -> List[str]:
     """Return list of rule ids skipped via comment on the line of yaml."""
     _before_noqa, _noqa_marker, noqa_text = line.partition("# noqa")
     noqa_text = noqa_text.lstrip(" :")
@@ -52,7 +52,7 @@ def get_rule_skips_from_line(line: str) -> List:
 
 def append_skipped_rules(
     pyyaml_data: "AnsibleBaseYAMLObject", lintable: Lintable
-) -> Sequence:
+) -> "AnsibleBaseYAMLObject":
     """Append 'skipped_rules' to individual tasks or single metadata block.
 
     For a file, uses 2nd parser (ruamel.yaml) to pull comments out of
@@ -62,8 +62,8 @@ def append_skipped_rules(
     :param pyyaml_data: file text parsed via ansible and pyyaml.
     :param file_text: raw file text.
     :param file_type: type of file: tasks, handlers or meta.
-    :returns: original pyyaml_data altered with a 'skipped_rules' list added
-    to individual tasks, or added to the single metadata block.
+    :returns: original pyyaml_data altered with a 'skipped_rules' list added \
+              to individual tasks, or added to the single metadata block.
     """
     try:
         yaml_skip = _append_skipped_rules(pyyaml_data, lintable)
@@ -71,23 +71,29 @@ def append_skipped_rules(
         # Notify user of skip error, do not stop, do not change exit code
         _logger.error('Error trying to append skipped rules', exc_info=True)
         return pyyaml_data
+
+    if not yaml_skip:
+        return pyyaml_data
+
     return yaml_skip
 
 
 @lru_cache(maxsize=128)
 def load_data(file_text: str) -> Any:
-    """Parse `file_text` as yaml and return parsed structure.
+    """Parse ``file_text`` as yaml and return parsed structure.
 
     This is the main culprit for slow performance, each rule asks for loading yaml again and again
-    ideally the `maxsize` on the decorator above MUST be great or equal total number of rules
+    ideally the ``maxsize`` on the decorator above MUST be great or equal total number of rules
     :param file_text: raw text to parse
     :return: Parsed yaml
     """
-    yaml = ruamel.yaml.YAML()
+    yaml = YAML()
     return yaml.load(file_text)
 
 
-def _append_skipped_rules(pyyaml_data: Sequence[Any], lintable: Lintable) -> Sequence:
+def _append_skipped_rules(
+    pyyaml_data: "AnsibleBaseYAMLObject", lintable: Lintable
+) -> Optional["AnsibleBaseYAMLObject"]:
     # parse file text using 2nd parser library
     ruamel_data = load_data(lintable.content)
 
@@ -99,7 +105,7 @@ def _append_skipped_rules(pyyaml_data: Sequence[Any], lintable: Lintable) -> Seq
     if lintable.kind in ('tasks', 'handlers'):
         ruamel_task_blocks = ruamel_data
         pyyaml_task_blocks = pyyaml_data
-    elif lintable.kind in ('playbook', 'pre_tasks', 'post_tasks'):
+    elif lintable.kind == 'playbook':
         try:
             pyyaml_task_blocks = _get_task_blocks_from_playbook(pyyaml_data)
             ruamel_task_blocks = _get_task_blocks_from_playbook(ruamel_data)
@@ -112,7 +118,7 @@ def _append_skipped_rules(pyyaml_data: Sequence[Any], lintable: Lintable) -> Seq
         return pyyaml_data
     else:
         # For unsupported file types, we return empty skip lists
-        return []
+        return None
 
     # get tasks from blocks of tasks
     pyyaml_tasks = _get_tasks_from_blocks(pyyaml_task_blocks)
@@ -132,7 +138,7 @@ def _append_skipped_rules(pyyaml_data: Sequence[Any], lintable: Lintable) -> Seq
     return pyyaml_data
 
 
-def _get_task_blocks_from_playbook(playbook: Sequence) -> List:
+def _get_task_blocks_from_playbook(playbook: Sequence[Any]) -> List[Any]:
     """Return parts of playbook that contains tasks, and nested tasks.
 
     :param playbook: playbook yaml from yaml parser.
@@ -151,7 +157,7 @@ def _get_task_blocks_from_playbook(playbook: Sequence) -> List:
     return task_blocks
 
 
-def _get_tasks_from_blocks(task_blocks: Sequence) -> Generator:
+def _get_tasks_from_blocks(task_blocks: Sequence[Any]) -> Generator[Any, None, None]:
     """Get list of tasks from list made of tasks and nested tasks."""
     NESTED_TASK_KEYS = [
         'block',
@@ -171,7 +177,7 @@ def _get_tasks_from_blocks(task_blocks: Sequence) -> Generator:
         yield task
 
 
-def _get_rule_skips_from_yaml(yaml_input: Sequence) -> Sequence:
+def _get_rule_skips_from_yaml(yaml_input: Sequence[Any]) -> Sequence[Any]:
     """Traverse yaml for comments with rule skips and return list of rules."""
     yaml_comment_obj_strs = []
 
